@@ -3,7 +3,7 @@ use 5.012;
 use Moo;
 
 # increment this whenever we break compat with older game objects
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Storable;
 use File::Spec::Functions;
@@ -32,7 +32,9 @@ sub move_tiles {
 	my ($self, $vec) = @_;
 	my $moved;
 
-	for my $cell ($vec->[0] > 0 || $vec->[1] > 0 ? reverse $self->tile_cells : $self->tile_cells) {
+	my $reverse = $vec->[0] > 0 || $vec->[1] > 0;
+
+	for my $cell (sort { $reverse } $self->tile_cells) {
 		my $tile = $self->tile($cell);
 		my $next = $cell;
 		my $farthest;
@@ -45,11 +47,26 @@ sub move_tiles {
 		if ($self->cells_can_merge($cell, $next)) {
 			# merge
 			my $next_tile = $self->tile($next);
-			$next_tile->merge($tile);
+
+			$tile->moving_from($cell);
+
+			$tile->merging_tiles(undef);
+			$tile->appear(undef);
+			$next_tile->merging_tiles(undef);
+			$next_tile->appear(undef);
+
+			my $merged_tile = Games::2048::Tile->new(
+				value => $tile->value + $next_tile->value,
+				merging_tiles => [ sort { $reverse } $tile, $next_tile ],
+				merged => 1,
+			);
+
 			$self->clear_tile($cell);
-			$self->score($self->score + $next_tile->value);
+			$self->set_tile($next, $merged_tile);
+
+			$self->score($self->score + $merged_tile->value);
 			$self->best_score($self->score) if $self->score > $self->best_score;
-			if ($next_tile->value >= 2048 and !$self->won) {
+			if ($merged_tile->value >= 2048 and !$self->won) {
 				$self->win(1);
 				$self->won(1);
 			}
@@ -57,21 +74,32 @@ sub move_tiles {
 		}
 		elsif (!$self->tile($farthest)) {
 			# slide
+			$tile->moving_from($cell);
+			$tile->merging_tiles(undef);
+			$tile->appear(undef);
+
 			$self->clear_tile($cell);
 			$self->set_tile($farthest, $tile);
 			$moved = 1;
 		}
 	}
 
+	$_->merged(0) for $self->each_tile;
+
 	return $moved;
 }
 
 sub move {
 	my ($self, $vec) = @_;
 	if ($self->move_tiles($vec)) {
-		$self->needs_redraw(1);
 		$self->insert_random_tile;
 
+		$self->needs_redraw(1);
+		$self->moving_vec($vec);
+		$self->moving(Games::2048::Animation->new(
+			duration => 0.2,
+		));
+
 		if (!$self->has_moves_remaining) {
 			$self->lose(1);
 		}
@@ -82,7 +110,6 @@ sub cells_can_merge {
 	my ($self, $cell, $next) = @_;
 	my $tile = $self->tile($cell);
 	my $next_tile = $self->tile($next);
-	$tile->merged(0) if $tile;
 	$tile and $next_tile and !$next_tile->merged and $next_tile->value == $tile->value;
 }
 
@@ -99,8 +126,10 @@ sub has_moves_remaining {
 }
 
 sub _game_file {
-	state $my_dist_method = "my_dist_" . ($^O eq "MSWin32" ? "data" : "config");
-	state $dir = eval { File::HomeDir->$my_dist_method("Games-2048", {create => 1}) };
+	state $dir = eval {
+		my $my_dist_method = "my_dist_" . ($^O eq "MSWin32" ? "data" : "config");
+		File::HomeDir->$my_dist_method("Games-2048", {create => 1});
+	};
 	return if !defined $dir;
 	return catfile($dir, "game.dat");
 }
